%%
% AWHSYN                (fixed-order) Anti-Windup Hinfinity-based SYNthesis
% -------------------------------------------------------------------------
%
% This function  computes a  fixed-order (possibly static) anti-windup com-
% pensator for a system affected by normalized deadzones. The method is ba-
% sed on wighted small-gain arguments and multi-objective Hinfinity optimi-
% zation. The anti-windup  compensator J(s) is computed to minimize the  H-
% infinity norm of the transfer from wh  to zh while  constraining the norm
% of the one from ws to zs.
%
%
%       ------------------------------------------------------
%      |                                   -----              |
%      |                           -------| DZN |<-----       | 
%      |                          |        -----       |      |
%      |                       ws |                    | zs   |
%      |                          |     -----------    |      |
%      |        --------           --->|           |---       |
%      |    v  |        |      w       |           |       v  |
%       ------>|  J(s)  |------------->|    M(s)   |----------
%              |        |              |           |               
%               --------       wh ---->|           |-----> zh
%                                       -----------          
% 
%
% The routine may be called in two ways:
%   * by a standard "matlab-only" approach
%   * by using the simulink interface SAWLIB
%
%
% STANDARD MATLAB CALL 
% --------------------
%  [J,crit]=awhsyn(sysM,ndz,nv,nw,order/poles)
%
%  * sysM     state-space description of the linear interconnection M(s) 
%  * ndz      number of deadzone functions
%  * nv       size of the anti-windup output signal v
%  * nw       size of the anti-windup input signal w
%  * order    order of the anti-windup compensator (poles not used)
%  * poles    poles of the anti-windup compensator (order not used)
%
% CALL SHORTCUT WITH SAWLIB INTERFACE
% -----------------------------------
%  [J,crit]=awhsyn(model,order/poles)
%
%  * model    name of the  Simulink diagram specifying the analysis problem
%             use the SAWLIB  Library and run  the short  demo to learn how
%             to generate compatible diagrams.
%  * order    order of the anti-windup compensator (poles not used)
%  * poles    poles of the anti-windup compensator (order not used)
%          
% OUTPUT ARGUMENTS
% ----------------
%  * J        anti-windup compensator
%  * crit     optimization criteria
%             crit(1) = ||T_{ws->zs}||_inf
%             crit(2) = ||T_{wh->zh}||_inf
%
% SEE ALSO
% --------
%  * SAWLIB   A specific Lib to generate compatible diagrams
%  * slksaw   Conversion routine
%  * satsan   Saturated systems analysis routine
%  * awlsyn   Anti-Windup design via Lyapunov-based approach
%
% -------------------------------------------------------------------------
% SMAC Toolbox ONERA The French Aerospace Lab, Toulouse, France
% SAAW Library for Saturated systems Analysis and Anti-Windup design
% Authors: J-M. Biannic and C. Roos
% Last revision: October 2015 by J-M. Biannic
% http://w3.onera.fr/smac
% -------------------------------------------------------------------------
