%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                A TUTORIAL EXAMPLE ON STABILITY ANALYSIS                 %
%               & ANTI-WINDUP DESIGN WITH THE SAW LIBRARY                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

path2saw;


% Nominal test without saturation
sim('ex1sim0');
figure(1); clf; plot(simout.time,simout.data);

% Test with saturations : unstable limit-cycle
w0=7.6175;
sim('ex1ana0');
figure(2); clf; plot(simout.time,simout.data);
figure(3); clf; plot(dzm.time,dzm.data);
hold on; plot(dzr.time,dzr.data,'r');

% Lyapunov Analysis : stability
w0=-1;
[P,crit]=satsan('ex1ana1');

% Lyapunov Analysis : performance
cc=[];
ww=1:0.2:4.2;
for w0=ww
    [P,crit]=satsan('ex1ana2');
    cc=[cc crit];
end;
figure(4); clf; plot(ww,cc);


% Anti-windup design 1 : stability augmentation
[J0,P,crit]=awlsyn('ex1dsg1');           % static      -> 12
[J1,P,crit1]=awlsyn('ex1dsg1','full');   % full-order  -> 26
[J2,P,crit2]=awlsyn('ex1dsg1',-1.8)      % fisrt-order -> 17
alphac=20;
J=J0; sim('ex1sim1');
figure(4); clf; plot(simout.time,simout.data(:,1),'r');
hold on;  plot(simout.time,simout.data(:,2),'k');
J=J1; sim('ex1sim1');
plot(simout.time,simout.data(:,2),'g');
J=J2; sim('ex1sim1');
plot(simout.time,simout.data(:,2),'b');


% Anti-windup design 2 : performance keeping
w0=7.6;
[J0,P,crit0]=awlsyn('ex1dsg2');           % static      -> 0.67
[J1,P,crit1]=awlsyn('ex1dsg2','full');    % full-order  -> 0.49
[J2,P,crit2]=awlsyn('ex1dsg2',[-7 -4+0.4*1i]);      % fisrt-order -> 0.57
[crit0 crit1 crit2]
alphac=10;
J=J0; sim('ex1sim1');
figure(4); clf; plot(simout.time,simout.data(:,1),'r');
hold on;  plot(simout.time,simout.data(:,2),'k');
J=J1; sim('ex1sim1');
plot(simout.time,simout.data(:,2),'g');
J=J2; sim('ex1sim1');
plot(simout.time,simout.data(:,2),'b');

