%%
% SATSAN                                         SATurated Systems ANalysis
% -------------------------------------------------------------------------
%
% This function computes  ellipsoidal stability regions and correlated per-
% formance levels for linear systems in closed-loop with several normalized
% deadzones operators resulting from static and symmetric saturations.
%
%                              -----
%                      -------| DZN |<-----
%                     |        -----       |
%                 ws  |                    |  zs
%                     |     -----------    | 
%                     |    |           |---
%                      --->|    M(s)   |
%                          |           |--->  zp
%                           -----------    
% 
% The optimized stability region is obtained as : E(P) = { x/ x'Px <= 1 }
% Various optimization  strategies are  available through the definition of
% a vector input argument w and the performance output signal zp.
%
% If  all components wi of w  are positive:                        
%   * P is constrainted such that E(P) contains wi*ui  with  ui=[0..1..0]'
%   * crit = output energy upper-bound for all initial condition in E(P)
%
% If w has negative components, let us preliminarily define:
%   I(w) : set of positive components indexes 
%   J(w) : set of negative components indexes 
%   * P is constrained such that E(P) contains wi*ui  with i in I(w)
%   * rho is maximized such that E(P) contains rho*uj with j in J(w)
%   * crit = rho
%
% WARNING! For well-posedness, at least one these two properties must hold:
%   * the input vector w has a negative component
%   * a valid output performance signal zp is defined
% 
% STANDARD MATLAB CALL 
% --------------------
%  [P,crit]=SATSAN(sysM,ndz,w,opt)
%
%  * sysM     state-space description of the linear interconnection M(s) 
%  * ndz      number of deadzone functions
%  * w        row vector [w1...wr] with r<=n shaping the stability domain.
%             wi is associated to the i-th state space direction ui
%              * wi>0  => constrains P / E(P) contains wi*ui 
%              * wi=-1 => maximizes rho / E(P) contains rho*ui
%  * opt      optional structured object with fields: 
%              * solver: LMI solver options (default = [0.01 1000 0 10 1]).
%
% CALL SHORTCUT WITH SAWLIB INTERFACE
% -----------------------------------
%  [P,crit]=SATSAN(model,opt)
%  
%  * model    name of the  Simulink diagram specifying the analysis problem
%             use the SAWLIB  Library and run  the short  demo to learn how
%             to generate compatible diagrams.
%          
% OUTPUT ARGUMENTS
% ----------------
%  * P        positive-definite  matrix defining  the ellipsoidal stability
%             region : E(P)={x/x'Px<=1}.
%  * crit     if w has negative entries:
%               * crit=max(rho) / E(P) contains rho*uj with j in J(w)
%             if w has only positive entries:
%               * crit = min(gamma) 
%                  forall x in E(P), ||zp|| < gamma
%                  and where E(P) contains wi*ui
%
% -------------------------------------------------------------------------
%    SMAC Toolbox ONERA The French Aerospace Lab, Toulouse, France
%    SAAW Library for Saturated systems Analysis and Anti-Windup design.
%    Authors: J-M. Biannic and C. Roos
%    Last revision: October 2015 by J-M. Biannic
%    http://w3.onera.fr/smac
% -------------------------------------------------------------------------
