%%
% SLKSAW       SimuLink diagrams => Stability Analysis or AntiWindup design
% -------------------------------------------------------------------------
%
% This function converts simulink diagrams generated with elements from the
% SAWLIB library into standard forms compatible with the stability analysis
% or anti-windup design routines (satsan, awlsyn, awhsyn)
%
%                              -----
%                      -------| DZN |<-----
%                     |        -----       |
%                 ws  |     -----------    |  zs
%                     |    |           |   | 
%                      --->|           |---
%                          |           |
%             aw_in ------>|    M(s)   |------> aw_out
%         ---------        |           |    
%        | EDI/DSI |------>|           |------> z   
%         ---------        |           |
%                           -----------
%
%
% CALL 
% ----
% [sysM,dim,w,crit] = SLKSAW(slkname)
%
% INPUT ARGUMENT
% --------------
%  * slkname  name of the Simulink file
% 
% OUTPUT ARGUMENTS
% ----------------
%  * sysM     state-space description of the linear interconnection M(s) 
%  * dim      structured array with fields
%             dim.sat=nosat;
%             dim.awi=nawi;
%             dim.awo=nawo;
%             dim.exi=nexi;
%             dim.exo=nexo;
%  * w        row  vector [w1...wr] associated  to the initial state of the
%             inputs generator blocks EDI/DSI
%  * crit     optimization criterion on z.
%             this output is not used in the current tools version.
%
% SEE ALSO
% --------
%  * SAWLIB   A specific Lib to generate compatible diagrams
%  * satsan   Saturated systems analysis routine
%  * awlsyn   Anti-Windup design via Lyapunov-based techniques
%  * awhsyn   Anti-Windup design via Hinfinity optimization
%
%
% -------------------------------------------------------------------------
% SMAC Toolbox ONERA The French Aerospace Lab, Toulouse, France
% SAAW Library for Saturated systems Analysis and Anti-Windup design.
% Author: J-M. Biannic
% Last revision: October 2015 by J-M. Biannic
% http://w3.onera.fr/smac
% -------------------------------------------------------------------------
